function create_gui(chapter, chapter_str)
%CREATE_GUI Create a GUI for m-files.
%
%   function create_gui(chapter, chapter_str)
%
%   Creates a GUI for a chapter in "Foundations of Antennas".

% By Ulf Carlberg.

% Prepare some variables we need for the GUI.
d = dir(sprintf('fig_%02d_*.m', chapter));
nfigs = numel(d);
edit_cmd  = cell(nfigs, 1);
run_cmd   = cell(nfigs, 1);
info_str1 = cell(nfigs, 1);
info_str2 = cell(nfigs, 1);
for ii = 1:nfigs
    filename = d(ii).name;
    
    % Callback command to edit a script.
    edit_cmd{ii} = ['edit(''' filename ''');'];
    
    % Callback command to run a script. Matlab can crash if the user tries to 
    % run a script while another script is not finished. Therefore we define the
    % variable "running" to avoid this.
    run_cmd{ii} = ['if ~exist(''running'',''var'') || running==0, ' ...
        'close_except(1); clearvars; running = 1; run ' filename(1:end-2) ...
        '; running = 0; end'];

    % Get info-text from each function to display in the GUI.
    try
        nr1 = str2double(filename(5:6));
        nr2 = str2double(filename(8:9));
        letter = filename(10);
        if letter=='_'
            letter = '';
        end
        info_str1{ii} = sprintf(' Fig. %d.%d%s:', nr1, nr2, letter);
    catch
        info_str1{ii} = ' Fig. ?.??:';
    end
    try
        f = fopen(filename, 'r'); tmp = fgetl(f); fclose(f);
        info_str2{ii} = tmp(3:end);
    catch
        info_str2{ii} = '(no info)';
    end
end

% Open the main window and put up the GUI.
h = figure;
wh = 70 + 50 + 30*nfigs + 20;
tmp = get(0, 'ScreenSize');
set(h, 'Position', [30 tmp(4)-wh-100 620 wh]);
uicontrol('Style', 'text', 'String', '', 'BackgroundColor', 0.8*[1 1 1], ...
    'Position', [0 0 620 wh]);
uicontrol('Style', 'text', 'String', ['Matlab scripts for the antenna book ' ...
    '"Foundations of Antennas" by Per-Simon Kildal'], ...
    'BackgroundColor', 0.8*[1 1 1], 'FontSize', 14, ...
    'HorizontalAlignment', 'left', 'Position', [10 wh-100 600 90]);
uicontrol('Style', 'text', 'String', sprintf(chapter_str,chapter), ...
    'BackgroundColor', 0.8*[1 1 1], 'FontSize', 14, ...
    'HorizontalAlignment', 'left', 'Position', [10 wh-130 600 50]);
for ii = 1:nfigs
    y = wh - 70 - 50 - 30*ii;
    uicontrol('Style', 'pushbutton', 'String', 'Run', 'TooltipString', ...
        'Run m-file', 'Position', [10 y 34 24], 'Callback', run_cmd{ii});
    uicontrol('Style', 'pushbutton', 'String', 'Edit', 'TooltipString', ...
        'Edit m-file', 'Position', [48 y 35 24], 'Callback', edit_cmd{ii});
    uicontrol('Style', 'text', 'String', info_str1{ii}, ...
        'BackgroundColor', 0.8*[1 1 1], 'FontSize', 10, ...
        'HorizontalAlignment', 'left', 'Position', [85 y-4 75 24]);
    uicontrol('Style', 'text', 'String', info_str2{ii}, ...
        'BackgroundColor', 0.8*[1 1 1], 'FontSize', 10, ...
        'FontAngle', 'italic', 'HorizontalAlignment', 'left', ...
        'Position', [160 y-4 450 24]);
end
if verLessThan('matlab', '8.4.0')
    h_nr_str = num2str(h);
else
    h_nr_str = num2str(h.Number);
end
uicontrol('Style', 'pushbutton', 'String', 'Close all', 'TooltipString', ...
    'Close all other figures and clear variables', ...
    'Position', [530 10 60 24], 'Callback', ...
    ['if ~exist(''running'',''var'') || running==0, running = 1; ' ...
    'close_except(' h_nr_str '); clearvars; end']);

end
