% Calculation of total reflection from two reflections.
%
% Complement to Figure 2.24 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
r1_dB = -17;
r2_dB = [-17 -20 -25 -30 -90];
Delta_z = 0.3;
freq = linspace(10e9, 12e9, 1001);
c = 2.99792458e8;

% Calculate total reflection.
beta = 2*pi*freq/c;
r1 = 10.^(r1_dB/20);
r2 = 10.^(r2_dB/20);
r2_tr = r2' * exp(-2j*beta*Delta_z);
abs_r_approx = abs(r1 + r2_tr);
r_approx_dB = 20*log10(abs_r_approx);
z1 = 2*r1 / (1-r1);
z2 = (1 + r2_tr) ./ (1 - r2_tr);
z_tot = z1 + z2;
r = (z_tot - 1) ./ (z_tot + 1);
r_dB = 20*log10(abs(r));

% Plot.
figure;
plot(freq/1e9, r_dB, '-');
hold on;
plot(freq/1e9, r_approx_dB, '--');
axis([min(freq)/1e9 max(freq)/1e9 -40 0]);
grid on;
xlabel('Frequency [GHz]');
ylabel('Total reflection coefficient [dB]');
lgnds = cell(1,2*numel(r2_dB));
for ii = 1:numel(lgnds)
    if ii<=numel(lgnds)/2
        lgnds{1,ii} = sprintf('Exact calc., r2 = %.0f dB', r2_dB(ii));
    else
        lgnds{1,ii} = sprintf('Approx. calc., r2 = %.0f dB', ...
            r2_dB(ii-numel(lgnds)/2));
    end
end
legend(lgnds, 'Location', 'northeast');
