% Diversity gain reduction from correlation.
%
% Complement to Figure 3.11 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Correlation coefficient.
rho = [0:0.01:0.89 0.900:0.001:1];

% Using the approximate expression in Eq. (3.13).
eff_reduction_approx = sqrt(1 - abs(0.99*rho).^2);
eff_reduction_approx_dB = 10*log10(eff_reduction_approx);

% Using the exact expression in reference.
Gamma = 10^(0/10);
cdf_level = 0.01;
eff_exact = zeros(size(rho));
for ii = 1:length(rho)
    abs_rho = abs(rho(ii));
    x = 10.^((eff_reduction_approx_dB(ii)+(-11:0.1:-9))/10);
    r = 2*x / (Gamma*(1-abs_rho^2));
    prob = 1 - 2*exp(-x/Gamma) .* marcumq(sqrt(r), sqrt(r)*abs_rho) + ...
        exp(-r) .* besseli(0, abs_rho*r);
    if abs_rho<1
        eff_exact(ii) = interp1(prob, x, cdf_level);
    end
end
eff_exact(abs(rho)==1) = eff_exact(rho==0).^2;
eff_reduction_exact = eff_exact ./ eff_exact(rho==0);
eff_reduction_exact_dB = 10*log10(eff_reduction_exact);

% Plot.
figure;
plot(rho, eff_reduction_approx_dB, 'r-', 'Linewidth', 1);
hold on;
plot(rho, eff_reduction_exact_dB, 'k--', 'Linewidth', 2);
ylim([-10 0]);
grid on;
legend('Approximate', 'Exact', 'Location', 'southwest');
xlabel('Correlation coefficient, \rho');
ylabel('Reduction of diversity gain (dB)');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig3-11.eps', 8*1.5, 5*1.5);
end
