% Radiation patterns of an incremental dipole and a halfwave dipole.
%
% Complement to Figure 4.9 in Foundations of Antennas by Per-Simon Kildal.

% Origninal version by Ulf Carlberg.
% Edited by Madeleine Kildal Schilliger 2014-07-09

% Define theta and phi angles.
theta_deg = 0:0.5:180;
phi_deg = -180:0.5:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);

% Far-field function (normalized) of a y-directed incremental electric current from
% Eq. (4.70).
G_id_theta = cos(theta) .* sin(phi);
G_id_phi = cos(phi);

% Far-field function (normalized) of a y-directed incremental magnetic current from
% Eq. (4.80).
G_im_theta = sin(phi);
G_im_phi = cos(theta) .* cos(phi);

% Far-field function (normalized) of a y-directed Huygens source from
% Eq. (4.81).
G_h_theta = 2*cos(theta/2).^2 .* sin(phi);
G_h_phi = 2*cos(theta/2).^2 .* cos(phi);


% Contour radiation pattern
% Plot
plot_contour_farfield(theta, phi, G_id_theta, G_id_phi,'yprim')
ha = axes('Position', [0 0 1 0.85], 'Xlim', [0 1], 'Ylim', [0 1], ...
    'Box', 'off', 'Visible', 'off', 'Units', 'normalized', 'clipping', 'off');
text(0.5, 1,'\bf Incremental electric current', 'HorizontalAlignment', 'center', ...
    'VerticalAlignment', 'top');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig4-09a.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig4-09a.png', 14, 10, 1000, 1, 0, 1);
    caxis([-30 0]);
    colormap(flipud(pink(10)));
    save_fig('Fig4-09agray.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig4-09agray.png', 14, 10, 1000, 1, 0, 1);
end

plot_contour_farfield(theta, phi, G_im_theta, G_im_phi,'yprim')
ha = axes('Position', [0 0 1 0.85], 'Xlim', [0 1], 'Ylim', [0 1], ...
    'Box', 'off', 'Visible', 'off', 'Units', 'normalized', 'clipping', 'off');
text(0.5, 1,'\bf Incremental magnetic current', 'HorizontalAlignment', 'center', ...
    'VerticalAlignment', 'top');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig4-09b.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig4-09b.png', 14, 10, 1000, 1, 0, 1);
    caxis([-30 0]);
    colormap(flipud(pink(10)));
    save_fig('Fig4-09bgray.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig4-09bgray.png', 14, 10, 1000, 1, 0, 1);
end

plot_contour_farfield(theta, phi, G_h_theta, G_h_phi,'yprim')
ha = axes('Position', [0 0 1 0.85], 'Xlim', [0 1], 'Ylim', [0 1], ...
    'Box', 'off', 'Visible', 'off', 'Units', 'normalized', 'clipping', 'off');
text(0.5, 1,'\bf Huygens source', 'HorizontalAlignment', 'center', ...
    'VerticalAlignment', 'top');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig4-09c.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig4-09c.png', 14, 10, 1000, 1, 0, 1);
    caxis([-30 0]);
    colormap(flipud(pink(10)));
    save_fig('Fig4-09cgray.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig4-09cgray.png', 14, 10, 1000, 1, 0, 1);
end