% Radiation patterns of a halfwave dipole.
%
% Complement to Figure 5.14c in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.
% Edited by Madeleine Kildal Schilliger

% Define theta and phi angles.
theta_deg = 0:0.5:180;
phi_deg = -180:0.5:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);

% Far-field function from Eq. (5.65).
h_lambda = 0.25;
kh = 2*pi*h_lambda;
G_hid_theta = cos(theta) .* sin(phi) .* sin(kh.*cos(theta));
G_hid_theta(cos(theta)<0) = 0;  % below ground plane
G_hid_phi = cos(phi) .* sin(kh.*cos(theta));
G_hid_phi(cos(theta)<0) = 0;  % below ground plane


%% Contour radiation pattern
% Plot
plot_contour_farfield(theta, phi, G_hid_theta, G_hid_phi,'yprim')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig5-14c.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig5-14c.png', 14, 10, 1500, 1, 0, 1);
    colormap(flipud(pink(15)));
    save_fig('Fig5-14cgray.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig5-14cgray.png', 14, 10, 1500, 1, 0, 1);
end

%% 3D radiation pattern
% Plot total 3D radiation pattern 
G_hid_tot = sqrt(abs(G_hid_theta).^2+abs(G_hid_phi).^2); %Equation 2.45
G_hid_tot_dB = 20*log10(G_hid_tot);
range_dB = 30;
G_hid_tot_dB_scaled = max(G_hid_tot_dB+range_dB,0) / range_dB;

figure;
zoomfactor = 0.5;
plot_3d_farfield_sub(theta, phi, G_hid_tot_dB_scaled)
zoom(zoomfactor)
if exist('savefigs', 'var') && savefigs
    save_fig('Fig5-14d.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig5-14d.png', 14, 10, 1500, 1, 0, 1);
end