% Directivity and radiation resistance of a horizontal dipole above a GP.
%
% Complement to Figure 5.15 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define theta angle and height above ground plane (unit wavelength).
h_lambda = 0:0.01:5;
theta_deg = (0:0.5:90)';

% Constants.
eta = 120*pi;
L_lambda = 1/50;
A = 0.5*eta*L_lambda;

% BOR1 radiation pattern from Eq. (5.65).
[theta, hh_lambda] = ndgrid(theta_deg*pi/180, h_lambda);
G_E = A * cos(theta) .* sin(2*pi*hh_lambda.*cos(theta));
G_H = A * sin(2*pi*hh_lambda.*cos(theta));

% Power integral of BOR1 radiation pattern.
P = pi * theta(2,1) * trapz(hypot(G_E,G_H).^2 .* sin(theta));

% Calculate gain, directivity, and radiation resistance.
G_0 = A * sin(2*pi*h_lambda);
D_0 = 10*log10(4*pi*abs(G_0).^2./P);
R = P/eta;

% Plot directivity and radiation resistance in same plot.
figure;
plot(h_lambda, D_0, 'b-', h_lambda, 40*R, 'r-');
axis([0 max(h_lambda) 0 10]);
grid on;
xlabel('Height [\lambda]');
legend('Directivity [dB]', '40 x Radiation resistance [ohm]');
