% Impedance of a horizontal dipole above ground.
%
% Complement to Figure 5.16 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define parameters.
Lmin = 0.3;
Lmax = 0.6;
a = [0.01 0.05 0.05 0.05];
h = [0.25 0.20 0.25 0.30];
t = 0.005;
Zref = 50;
pstyle = {'b-', 'r-', 'g-', 'k-'};

% Calculate and plot for different dipole thicknesses.
figure;
lbls = cell(numel(a), 1);
for ii = 1:numel(a)
    [Ldip, Zdip] = impedance_dipole_thinwire_gp(Lmin, Lmax, t, a(ii), h(ii));
    S11 = (Zdip-Zref) ./ (Zdip+Zref);
    lbls{ii} = sprintf('a = %.2f \\lambda, h = %.2f \\lambda', a(ii), h(ii));
    plot(Ldip, 20*log10(abs(S11)), pstyle{ii});
    hold on;
end
xlabel('Dipole length [\lambda]');
ylabel('Reflection coefficient [dB]');
axis([Lmin Lmax -30 0]);
grid on;
legend(lbls, 'Location', 'southeast');
