% Radiation patterns of a halfwave dipole.
%
% Complement to Figure 5.22b in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.
% Edited by Madeleine Kildal Schilliger

% Define theta and phi angles.
theta_deg = 0:0.5:180;
phi_deg = -180:0.5:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);

% Far-field function from Eq. (5.82)-(5.85).
%l_lambda = 0.5; %Half a wavelength slot.
sc = sin(theta) .* cos(phi);
M = cos(0.5*pi*sc) ./ (1 - sc.^2);
ind = find((1-sc.^2) == 0); %Use l'Hopital's rule to get the correct values
M(ind) = pi/4;
G_slt_theta = -sin(phi) .* M;
G_slt_theta(cos(theta)<0) = 0;  % below ground plane
G_slt_phi = -cos(theta) .* cos(phi) .*M;
G_slt_phi(cos(theta)<0) = 0;  % below ground plane

%% Contour radiation pattern
% Plot
plot_contour_farfield(theta, phi, G_slt_theta, G_slt_phi,'yprim')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig5-22b.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig5-22b.png', 14, 10, 1000, 1, 0, 1);
    colormap(flipud(pink(15)));
    save_fig('Fig5-22bgray.eps', 14, 10, 450, 1, 0, 0);
    save_fig('Fig5-22bgray.png', 14, 10, 1000, 1, 0, 1);
end

%% 3D radiation pattern
% Plot total 3D radiation pattern 
G_slt_tot = sqrt(abs(G_slt_theta).^2+abs(G_slt_phi).^2); %Equation 2.45
G_slt_tot_dB = 20*log10(G_slt_tot);
range_dB = 30;
G_slt_tot_dB_scaled = max(G_slt_tot_dB+range_dB,0) / range_dB;

figure;
zoomfactor = 0.5;
plot_3d_farfield_sub(theta, phi, G_slt_tot_dB_scaled)
zoom(zoomfactor)
if exist('savefigs', 'var') && savefigs
    save_fig('Fig5-22c.eps', 14, 10, 450, 1, 0, 0);
end
