% Admittance calculation for a voltage excited slot.
%
% Complement to Figure 5.24 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define parameters.
Lmin = 0.3;
Lmax = 0.6;
w = 0.01;
t = 0.0025;
eta = 120*pi;

% Calculate for microstrip dipole.
[Ldip, Zdip] = impedance_dipole_microstrip(Lmin, Lmax, t, w);

% Admittance of slot is related to impedance of microstrip according to
% Eq. (5.91).
Yslot = 4*Zdip/eta.^2;

% Plot admittance.
figure;
plot(Ldip, 500*real(Yslot), 'b-', Ldip, 500*imag(Yslot), 'r-');
xlabel('Slot length [\lambda]');
ylabel('500*G and 500*B [S]');
axis([Lmin Lmax -1 2]);
grid on;
legend('500*G', '500*B', 'Location', 'southeast');
