% Universal radiation pattern of a uniform rectangular aperture.
%
% Complement to Figure 7.12 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define input variable.
x = 0:0.01:6;

% Define aperture distribution for comparison.
u = linspace(-0.5, 0.5, 101);
Eap = cos(pi*u);

% Fourier transform using Eq. (7.30).
BB1 = zeros(size(x));
for ii = 1:numel(x)
    BB1(ii) = trapz(Eap.*exp(2j*pi*x(ii)*u));
end
BB1 = BB1 ./ trapz(Eap);

% Calculate the uniform aperture from Eq. (7.43). It is a sinc-function.
b = 1;
phi = pi/2;
BB2 = b * sinc(x*sin(phi));

% Plot.
figure;
plot(x, 20*log10(abs(BB1)), 'k--', x, 20*log10(abs(BB2)), 'b-');
axis([0 6 -40 0]);
grid on;
xlabel('(b/\lambda) sin(\theta)');
ylabel('Relative co-polar level [dB]');
legend('Comparison', 'Uniform aperture');
