% Radiation pattern of a uniform rectangular aperture in E- and H-plane.
%
% Complement to Figure 7.13 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define input variable.
a_lambda = 8;
b_lambda = 8;

% Define angles.
theta_deg = -180:0.1:180;
theta = theta_deg*pi/180;

% E-plane patterns from Eq. (7.31) and Eq. (7.32).
G_E_PEC = sinc(b_lambda*sin(theta));
G_E_PEC(cos(theta)<0) = 0;  % below ground plane
G_E_FS = cos(theta/2).^2 .* sinc(b_lambda*sin(theta));

% H-plane patterns from Eq. (7.33) and Eq. (7.34).
G_H_PEC = cos(theta) .* sinc(a_lambda*sin(theta));
G_H_PEC(cos(theta)<0) = 0;  % below ground plane
G_H_FS = cos(theta/2).^2 .* sinc(a_lambda*sin(theta));

% Plot.
figure;
plot(theta_deg, 20*log10(abs(G_E_PEC)), 'b-' , ...
     theta_deg, 20*log10(abs(G_E_FS )), 'g-' , ...
     theta_deg, 20*log10(abs(G_H_PEC)), 'r-', ...
     theta_deg, 20*log10(abs(G_H_FS )), 'k--');
axis([0 90 -40 0]);
grid on;
xlabel('\theta [deg]');
ylabel('Relative co-polar level [dB]');
legend('E-plane PEC', 'E-plane free-space', 'H-plane PEC', ...
    'H-plane free-space');
