% Surface plot of the universal rad. pattern of a uniform rectangular aperture.
%
% Complement to Figure 7.14 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define parameters and calculate.
u = -4:0.01:4;
v = -3:0.01:3;
min_dB = -35;
[uu, vv] = ndgrid(u, v);
AA = sinc(uu);
BB = sinc(vv);
AABB = AA .* BB;
AABB_dB = max(20*log10(abs(AABB)), min_dB);

% Find level of first sidelobes. It is the (first) minimum of the sinc
% function.
x = 1.4:0.0001:1.5;
[~, indx] = min(sinc(x));
x_sidelobe = x(indx);
y_sidelobe_dB = 20*log10(abs(sinc(x_sidelobe)));

% Plot a rotatable surface.
figure;
AABB_dB(end,end) = -100;  % hack to avoid graphic glitch when saving plot
surf(uu, vv, AABB_dB);
colormap(jet(-min_dB/2.5));
hold on;
plot3(-x_sidelobe, 0, y_sidelobe_dB+0.1, 'k+', ...
      +x_sidelobe, 0, y_sidelobe_dB+0.1, 'k+', ...
      0, -x_sidelobe, y_sidelobe_dB+0.1, 'k+', ...
      0, +x_sidelobe, y_sidelobe_dB+0.1, 'k+');
shading flat;
title('Radiation from a uniform rectangular aperture');
fs = 8;
% xlabel('$\textsf{u = sin($\theta$) cos($\varphi$) a/$\lambda$}$', 'Interpreter', 'latex', 'FontSize', fs);
% ylabel('$\textsf{v = sin($\theta$) sin($\varphi$) b/$\lambda$}$', 'Interpreter', 'latex', 'FontSize', fs);
xlabel('u = sin(\theta) cos(\phi) a/\lambda', 'Interpreter', 'tex');
ylabel('v = sin(\theta) sin(\phi) b/\lambda', 'Interpreter', 'tex');
view(0, 90);
caxis([-35 0]);
hb = colorbar;
axis image;
set(gca, 'TickDir', 'out');
grid off;
box on;
colorTitleHandle = get(hb,'Title');
titleString = 'dB';
set(colorTitleHandle ,'String',titleString);

annotation('textbox', [0.55,0.04,0.4,0.04], 'String', ...
    sprintf('+ First sidelobes %.1f dB at %.3f', ...
    y_sidelobe_dB, x_sidelobe), 'LineStyle', 'none');
set(gca, 'XTickMode', 'manual');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig7-14.png', 14, 10, 1500);
    colormap(flipud(gray(-min_dB/5)));
    save_fig('Fig7-14gray.png', 14, 10, 1500);
end