% Universal radiation pattern of a BOR1 circular aperture.
%
% Complement to Figure 7.16 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define input variable.
d_lambda_sin_theta = 0:0.01:6;

% Uniform aperture distribution using Eq. (7.62).
EEco45_uni = besselj(1, pi*d_lambda_sin_theta) ./ (pi*d_lambda_sin_theta);
EEco45_uni = EEco45_uni ./ max(EEco45_uni);

% Aperture distribution J0 tapered to zero using Eq. (7.57).
rho_norm = linspace(0, 0.5, 101);
k01 = 2.405;
Eco45_norm = besselj(0, k01*2*rho_norm);
EEco45_J0 = zeros(size(d_lambda_sin_theta));
for ii = 1:numel(d_lambda_sin_theta)
    EEco45_J0(ii) = diff(rho_norm(1:2)) * trapz(Eco45_norm .* ...
        besselj(0, 2*pi*d_lambda_sin_theta(ii)*rho_norm) .* rho_norm);
end
EEco45_J0 = EEco45_J0 ./ max(EEco45_J0);

% Plot.
figure;
plot(d_lambda_sin_theta, 20*log10(abs(EEco45_uni)), 'b-', ...
     d_lambda_sin_theta, 20*log10(abs(EEco45_J0 )), 'k--');
axis([0 6 -60 0]);
grid on;
xlabel('(d/\lambda) sin(\theta)');
ylabel('Relative level [dB]');
legend('Uniform aperture', 'J_0 tapered to zero');
