% Inifinite Gaussian aperture distribution and its radiation pattern.
%
% Complement to Figure 7.18 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Aperture distribution using Eq. (7.64).
rho_over_rho_a = -3:0.01:3;
E_a = exp(-rho_over_rho_a.^2);

figure;
plot(rho_over_rho_a, E_a, 'b-', [-3 3], [exp(-1) exp(-1)], 'k-');
grid on;
xlabel('\rho/\rho_a');
ylabel('Aperture distribution');
legend('E_a', '1/e');

% Radiation pattern.
sin_theta_over_sin_theta_a = -3:0.01:3;
G_dB = 20*log10(exp(-1)) * sin_theta_over_sin_theta_a .^ 2;

figure;
plot(rho_over_rho_a, G_dB, 'b-');
axis([-3 3 -60 0]);
grid on;
xlabel('sin(\theta)/sin(\theta_a)');
ylabel('Relative level [dB]');
