% E-plane sector horn.
%
% Complement to Figure 8.9 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
a_lambda = 0.5;   % aperture width in H-plane
b_lambda = 2.75;  % aperture width in E-plane
L_lambda = 6;     % flare length

% Theta angles.
theta_deg = 0:180;
theta = theta_deg*pi/180;

% Calculate.
kxa = 2 * pi * a_lambda * sin(theta);
kyb = 2 * pi * b_lambda * sin(theta);
Phi_max = 2 * pi * b_lambda.^2 / (8*L_lambda);
G_H = zeros(size(theta));
G_E = zeros(size(theta));
u = linspace(-1, 1, 201);
du = u(2) - u(1);
for ii = 1:numel(theta)
    Hint = cos(pi*u/2) .* exp(1j*kxa(ii)*u/2);  % Eq. (8.10)
    Eint = exp(-1j*u.^2*Phi_max) .* exp(1j*kyb(ii)*u/2);  % Eq. (8.12)
    G_H(ii) = trapz(Hint)*du * cos(theta(ii)/2).^2; 
    G_E(ii) = trapz(Eint)*du * cos(theta(ii)/2).^2; 
end
G_H = G_H / G_H(1);
G_E = G_E / G_E(1);

% Plot.
figure;
plot(theta_deg, 20*log10(abs(G_H)), 'b-', theta_deg, 20*log10(abs(G_E)), 'r-');
axis([min(theta_deg) max(theta_deg) -40 0]);
grid on;
legend('H-plane', 'E-plane');
title('E-plane sector horn');
xlabel('\theta [deg]');
ylabel('Relative level [dB]');
