% H-plane sector horn.
%
% Complement to Figure 8.12 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
a_lambda = 5.50;  % aperture width in H-plane
b_lambda = 0.25;  % aperture width in E-plane
L_lambda = 6.00;  % flare length

% Theta angles.
theta_deg = 0:180;
theta = theta_deg*pi/180;

% Calculate.
Phi_max = 2 * pi * a_lambda^2 / (8*L_lambda);
G_H = zeros(size(theta));
G_E = zeros(size(theta));
u = linspace(-1, 1, 201);
du = u(2) - u(1);
for ii = 1:numel(theta)
    Hint = cos(pi*u/2) .* exp(1j*(-Phi_max*u.^2+pi*sin(theta(ii))*a_lambda*u));
        % Eq. (8.18)
    Eint = exp(1j*pi*sin(theta(ii))*b_lambda*u);  % Eq. (8.19)
    G_H(ii) = trapz(Hint)*du * cos(theta(ii)/2).^2; 
    G_E(ii) = trapz(Eint)*du * cos(theta(ii)/2).^2; 
end
G_H = G_H / G_H(1);
G_E = G_E / G_E(1);

% Plot.
figure;
plot(theta_deg, 20*log10(abs(G_H)), 'b-', theta_deg, 20*log10(abs(G_E)), 'r-');
axis([min(theta_deg) max(theta_deg) -40 0]);
grid on;
legend('H-plane', 'E-plane');
title('H-plane sector horn');
xlabel('\theta [deg]');
ylabel('Relative level [dB]');
