% Directivity of a pyramidal horn from dimensions.
%
% Complement to Chapter 8 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
b = 40;       % E-plane aperture width in [mm]
a = 40;       % H-plane aperture width in [mm]
bw = 20;      % E-plane waveguide width in [mm]
aw = 10;      % H-plane waveguide width in [mm]
Lf = 200;     % flare length along edge in [mm]
lambda = 15;  % wavelength in [mm]

% Geometry calculations.
k = 2*pi / lambda;  % wave number [rad/mm]
Lfb = b * Lf / (b-bw);  % flare length along edge from apex [mm]
Lfa = a * Lf / (a-aw);  % flare length along edge from apex [mm]
Lfy = sqrt(Lfb^2-(b/2)^2);  % flare length along center line wall [mm]
Lfx = sqrt(Lfa^2-(a/2)^2);  % flare length along center line wall [mm]
Ly = sqrt(Lfy^2-(a/2)^2);  % radius of wavefront curvature
Lx = sqrt(Lfx^2-(b/2)^2);  % radius of wavefront curvature

% Aperture integration (spherical phase).
bb = linspace(-b/2, b/2, 401);
db = bb(2) - bb(1);
ey = abs(db*trapz(exp(-1j*k*(hypot(Ly,bb)-Ly))))^2 / b^2;
aa = linspace(-a/2, a/2, 401);
da = aa(2) - aa(1);
ex = abs(da*trapz(exp(-1j*k*(hypot(Lx,aa)-Lx)).*cos(pi*aa/a))).^2 / ...
    (a * da*trapz(abs(cos(pi*aa/a)).^2));

% Total aperture efficiency and directivity.
eap = ex*ey;
D = 4*pi*eap*a*b / lambda^2;
eap_dB = 10*log10(eap);
D_dB = 10*log10(D);
fprintf('Total aperture efficiency = %.3f dB\n', eap_dB);
fprintf('Directivity = %.3f dB\n', D_dB);
