% Universal radiation pattern of a smooth conical horn in the 45 deg plane.
%
% Complement to Figure 8.20 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input parameters.
Phi_max_deg = 0:90:360;
x = 0:0.01:6;  % 2*a/lambda*sin(theta)

% Calculate Eq. (8.56) and Eq. (8.57).
kappa1 = 1.841;  % besselj(1,x) has maximum at x=kappa1
u = linspace(0, 1, 401);
[xx, uu] = ndgrid(x, u);
lgnds = cell(numel(Phi_max_deg), 2);
Eco45 = zeros(numel(x), numel(Phi_max_deg));
Exp45 = zeros(numel(x), numel(Phi_max_deg));
for ii = 1:numel(Phi_max_deg)
    Phi_max = Phi_max_deg(ii) * pi / 180;
    tmp0 = besselj(0, kappa1*u) .* exp(-1j*Phi_max*u.^2) .* u;
    tmp2 = besselj(2, kappa1*u) .* exp(-1j*Phi_max*u.^2) .* u;
    Eco45(:,ii) = trapz(bsxfun(@times, tmp0, besselj(0,pi*xx.*uu)), 2);
    Exp45(:,ii) = trapz(bsxfun(@times, tmp2, besselj(2,pi*xx.*uu)), 2);
    Exp45(:,ii) = Exp45(:,ii) / Eco45(1,ii);
    Eco45(:,ii) = Eco45(:,ii) / Eco45(1,ii);
    lgnds{ii,1} = sprintf('CO (\\Phi_{max} = %.0f deg)', Phi_max_deg(ii));
    lgnds{ii,2} = sprintf('XP (\\Phi_{max} = %.0f deg)', Phi_max_deg(ii));
end
Gco45_dB = 20*log10(abs(Eco45));
Gxp45_dB = 20*log10(abs(Exp45));

% Plot.
figure;
plot(x, Gco45_dB, '-' ); hold on;
plot(x, Gxp45_dB, '--');
axis([min(x) max(x) -35 5]);
grid on;
title('Smooth conical horn');
xlabel('(2a/\lambda)sin(\theta)');
ylabel('Relative level [dB]');
legend(lgnds(:));
