% Directivity as a function of beam angle for a Gaussian beam.
%
% Complement to Figure 8.24 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
theta_e_deg = logspace(log10(1), log10(100), 400)';  % beam angle
level_dB = [-3 -5 -8.69 -10:-5:-25];

% Calculate.
theta_e_sq = (theta_e_deg*pi/180).^2;
D_dB = zeros(numel(theta_e_deg), numel(level_dB));
lgnds = cell(1, numel(level_dB));
for ii = 1:numel(level_dB)
    theta_0_sq = -8.69*theta_e_sq/level_dB(ii);
    D_dB(:,ii) = 10*log10(8 ./ theta_0_sq);
    lgnds{ii} = sprintf('%.1f dB', level_dB(ii));
end

% Plot.
figure;
semilogx(theta_e_deg, D_dB);
axis([1 100 0 50]);
grid on;
xlabel('Beam angle \theta_e [deg]');
ylabel('Directivity [dBi]');
legend(lgnds);
    