% Directivity from aperture diameter and flare angle of a soft horn.
%
% Complement to Figure 8.25 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
alpha_deg = [0 3 5 7 10 15 20 30 45 60 90];  % flare angles
D = logspace(log10(1), log10(100), 400)';    % aperture diameter [lambda]

% Calculate.
[DD, alpha] = ndgrid(D, alpha_deg*pi/180);
rho_a = 0.59*DD*0.5;  % Gaussian aperture width
theta_diff_sq = (2./(2*pi*rho_a)).^2;
theta_GO_sq = (0.59*alpha).^2;
theta_0_sq = theta_diff_sq + theta_GO_sq;
Dir_dB = 10*log10(8./theta_0_sq);
theta_0_sq_max = 2*theta_diff_sq;
Dir_max_dB = 10*log10(8./theta_0_sq_max);

% Plot.
figure;
semilogx(D, Dir_dB); hold on;
semilogx(D, Dir_max_dB, 'k--');
axis([1 100 5 50]);
grid on;
xlabel('Aperture diameter [\lambda]');
ylabel('Directivity [dBi]');
iD = round(0.95*numel(D));
for ii = 1:numel(alpha_deg)
    text(D(iD), Dir_dB(iD,ii), num2str(alpha_deg(ii)), ...
        'BackgroundColor', [1 1 1]);
end
