% Phase center from aperture d. and flare angle of a soft horn.
%
% Complement to Figure 8.26 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
alpha_deg = [0 3 5 7 10 15 20 30 45 60 90];  % flare angles
D = logspace(log10(1), log10(100), 400)';    % aperture diameter [lambda]

% Calculate.
[DD, alpha] = ndgrid(D, alpha_deg*pi/180);
rho_a = 0.59*DD*0.5;  % Gaussian aperture width
theta_diff_sq = (2./(2*pi*rho_a)).^2;
theta_GO_sq = (0.59*alpha).^2;
theta_0_sq = theta_diff_sq + theta_GO_sq;
z_pc = -theta_GO_sq ./ theta_0_sq;
theta_0_sq_max = 2*theta_diff_sq;
z_pc_max = -0.5*ones(size(D));

% Plot.
figure;
semilogx(D, z_pc); hold on;
semilogx(D, z_pc_max, 'k--');
axis([1 100 -1 0]);
grid on;
xlabel('Aperture diameter [\lambda]');
ylabel('Phase center location z_{pc}/L [-]');
iD = round(linspace(0.75,0.25,numel(alpha_deg))*numel(D));
for ii = 1:numel(alpha_deg)
    text(D(iD(ii)), z_pc(iD(ii),ii), num2str(alpha_deg(ii)), ...
        'BackgroundColor', [1 1 1]);
end
