% Phase efficiency of a Cassegrain antenna.
%
% Complement to Figure 9.11 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
delta = logspace(log10(0.1),log10(20),500);  % phase displacement [lambda]
theta_0_deg = [10 20 30 60 90];              % subtended half angle
A0_dB = [0 20];                              % feed illumination taper

% Calculate with Eq. (9.88) - Eq. (9.91).
eff = zeros(numel(delta), numel(theta_0_deg), numel(A0_dB));
lgnds = cell(numel(theta_0_deg), numel(A0_dB));
for it = 1:numel(theta_0_deg)
    theta_0 = theta_0_deg(it)*pi/180;
    t = linspace(0, theta_0, 200);
    for ia = 1:numel(A0_dB)
        n = A0_dB(ia) / (-20*log10(cos(theta_0/2)));
        Iw   = t(2) * trapz( cos(t/2).^n .* tan(t/2)                  );
        Iwc  = t(2) * trapz( cos(t/2).^n .* tan(t/2) .* (cos(t)-1)    );
        Iwc2 = t(2) * trapz( cos(t/2).^n .* tan(t/2) .* (cos(t)-1).^2 );
        a = Iwc2/Iw - (Iwc/Iw).^2;
        eff(:,it,ia) = exp(-a*(2*pi*delta).^2);
        lgnds{it,ia} = sprintf('\\theta_0 = %.0f deg, Taper %.0f dB', ...
            theta_0_deg(it), A0_dB(ia));
    end
end

% Plot.
figure;
semilogx(delta, 10*log10(abs(eff(:,:,1))), '-'); hold on;
semilogx(delta, 10*log10(abs(eff(:,:,2))), '--');
axis([min(delta) max(delta) -2 0]);
grid on;
title('Cassegrain antenna');
xlabel('Phase displacement \delta/\lambda [-]');
ylabel('Phase efficiency [dB]');
legend(lgnds(:));
