% Phase center tolerance of a Cassegrain antenna.
%
% Complement to Figure 9.12 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
theta_0_deg = logspace(log10(1),log10(100),500);  % subtended half angle
A0_dB = [0 20];                                   % feed illumination taper

% Calculate with Eq. (9.88) - Eq. (9.91).
delta = zeros(numel(theta_0_deg), numel(A0_dB));
lgnds = cell(1, numel(A0_dB));
for it = 1:numel(theta_0_deg)
    theta_0 = theta_0_deg(it)*pi/180;
    t = linspace(0, theta_0, 200);
    for ia = 1:numel(A0_dB)
        n = A0_dB(ia) / (-20*log10(cos(theta_0/2)));
        Iw   = t(2) * trapz( cos(t/2).^n .* tan(t/2)                  );
        Iwc  = t(2) * trapz( cos(t/2).^n .* tan(t/2) .* (cos(t)-1)    );
        Iwc2 = t(2) * trapz( cos(t/2).^n .* tan(t/2) .* (cos(t)-1).^2 );
        a = Iwc2/Iw - (Iwc/Iw).^2;
        delta(it,ia) = 0.151 / (2*pi*sqrt(a));
        if it==1
            lgnds{ia} = sprintf('Taper %.0f dB', A0_dB(ia));
        end
    end
end

% Plot.
figure;
loglog(theta_0_deg, delta);
axis([min(theta_0_deg) max(theta_0_deg) 0.07 700]);
grid on;
title('Cassegrain antenna');
xlabel('Phase displacement \delta/\lambda [-]');
ylabel('Phase efficiency [dB]');
legend(lgnds(:));
