% Universal radiation pattern with the array factor.
%
% Complement to Figure 10.5 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
x = (0:0.05:24)';  % L/lambda*cos(alpha)
N = [10 22 Inf];   % number of elements in antenna array

% Calculate.
[xx, NN] = ndgrid(x, N);
AF = sin(pi*xx) ./ (NN.*sin(pi*xx./NN));

% Taylor expansions to remove glitches in curves.
indx1 = abs(sin(0.5*pi*(  xx./NN))) < 1e-8;
indx2 = abs(sin(0.5*pi*(1+xx./NN))) < 1e-8;
indx3 = NN > 1e30;
indx4 = abs(xx) < 1e-8;
AF(indx1) = 1;
AF(indx2) = 2*mod(NN(indx2),2) - 1;
AF(indx3) = sin(pi*xx(indx3)) ./ (pi*xx(indx3));
AF(indx4) = 1;

% Plot.
figure;
plot(x, 20*log10(abs(AF)));
axis([min(x) max(x) -40 0]);
grid on;
xlabel('(L/\lambda)cos(\alpha)');
ylabel('Relative level [dB]');
lgnds = cell(numel(N), 1);
for ii = 1:numel(N)
    lgnds{ii} = sprintf('N = %d', N(ii));
end
legend(lgnds, 'Location', 'southeast');
