% Element pattern and array factor.
%
% Complement to Figure 10.7 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
cos_alpha = (-2:0.005:2)';
alpha_g_deg = 45;
N = 14;            % number of elements in antenna array
d = 0.7;           % element spacing [lambda]
alpha_0_deg = 90;  % main beam direction from endfire [deg]

% Antenna array factor.
alpha_0 = alpha_0_deg*pi/180;
k = 2*pi;
AF = sin(N*(cos_alpha-cos(alpha_0))*k*d/2) ./ ...
     (N*sin((cos_alpha-cos(alpha_0))*k*d/2));
AF_dB = 20*log10(abs(AF));

% Element pattern.
cos_alpha_g = cos(alpha_g_deg*pi/180);
Ged_dB = -8.69 * (cos_alpha/cos_alpha_g).^2;
Ged_dB(abs(cos_alpha)>1) = -80;

% Total radiation pattern.
G_dB = AF_dB + Ged_dB;

% Plot array factor.
figure;
plot(cos_alpha, AF_dB); hold on;
plot(cos(alpha_0), 0, 'ko');
text(cos(alpha_0), 1, sprintf('\\alpha = %.0f deg', alpha_0_deg));
axis([min(cos_alpha) max(cos_alpha) -30 5]);
grid on;
title('Normalized array factor');
xlabel('cos(\alpha) [-]');
ylabel('Relative level [dB]');

% Plot element pattern.
figure;
plot(cos_alpha, Ged_dB);
axis([min(cos_alpha) max(cos_alpha) -30 5]);
grid on;
title('Element pattern');
xlabel('cos(\alpha) [-]');
ylabel('Relative level [dB]');

% Plot total pattern.
figure;
plot(cos_alpha, Ged_dB, cos_alpha, G_dB); hold on;
[~, indx] = min(abs(cos_alpha-cos(alpha_0)));
plot(cos(alpha_0), G_dB(indx), 'ko');
text(cos(alpha_0)+0.1, G_dB(indx), sprintf('\\alpha = %.0f deg', alpha_0_deg));
axis([min(cos_alpha) max(cos_alpha) -30 5]);
grid on;
title('Normalized total pattern');
xlabel('cos(\alpha) [-]');
ylabel('Relative level [dB]');
legend('Element pattern', 'Element pattern and array factor', ...
    'Location', 'southeast');
