% Element pattern in array.
%
% Complement to Figure 10.17a in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Definition of the embedded element pattern.
A0_E_dB = 35;  % taper in E-plane [dB]
A0_H_dB = 10;  % taper in H-plane [dB]
theta0_E_deg = 90;  % angle of taper value in E-plane [deg]
theta0_H_deg = 90;  % angle of taper value in H-plane [deg]
plot_min_dB = -16;  % lower limit of level in surface plot [dB]

% Define cos^n pattern with y' polarization.
ne = A0_E_dB / (-20*log10(cosd(theta0_E_deg/2)));
nh = A0_H_dB / (-20*log10(cosd(theta0_H_deg/2)));
[theta, phi] = ndgrid(linspace(0,pi/2,501), linspace(-pi,pi+0.001,2001));
G_theta = cos(theta/2).^ne .* sin(phi);
G_phi   = cos(theta/2).^nh .* cos(phi);
G_co = sin(phi).*G_theta + cos(phi).*G_phi;  % Eq. (2.55)
G_xp = cos(phi).*G_theta - sin(phi).*G_phi;  % Eq. (2.56)
G_co_dB = 20*log10(abs(G_co));
G_co_dB(G_co_dB<plot_min_dB) = plot_min_dB;
G_co_dB(1,1) = -100;  % avoid graphic glitch

% Plot element pattern.
figure;
surf(sin(theta).*cos(phi), sin(theta).*sin(phi), G_co_dB);
hold on;
plot(cos(phi(1,:)), sin(phi(1,:)), 'k-');
colormap(jet(-plot_min_dB));
view(0, 90);
title('Normalized element pattern');
fs = 8;
%xlabel('$\textsf{u = sin($\theta$) cos($\varphi$)}$', 'Interpreter', 'latex', 'FontSize', fs);
%ylabel('$\textsf{v = sin($\theta$) sin($\varphi$)}$', 'Interpreter', 'latex', 'FontSize', fs);
xlabel('u = sin(\theta) cos(\phi)', 'Interpreter', 'tex');
ylabel('v = sin(\theta) sin(\phi)', 'Interpreter', 'tex');
grid off;
box on;
axis([-1 1 -1 1]);
axis image;
shading flat;
hb = colorbar;
caxis([plot_min_dB 0]);
colorTitleHandle = get(hb,'Title');
titleString = 'dB';
set(colorTitleHandle ,'String',titleString);

if exist('savefigs', 'var') && savefigs
    save_fig('Fig10-17a.png', 14, 10, 1000);
    colormap(flipud(pink(-plot_min_dB/2)));
    save_fig('Fig10-17agray.png', 14, 10, 1000);
end