function Q = marcumq(a, b, m)
%Marcum Q-function
%
%   function Q = marcumq(a, b, m)
%
%   Simple (slow) implementation of the Marcum Q-function. Default m=1.
%
%   http://en.wikipedia.org/wiki/Marcum_Q-function

% By Ulf Carlberg

if nargin<3, m = 1; end

t = linspace(0, 10, 1001);
Q = zeros(size(a));
for ii = 1:numel(a)
    x = t + b(ii);
    integrand = x .* (x/a(ii)).^(m-1) .* exp(-0.5*(x.^2+a(ii)^2)) .* ...
        besseli(m-1, a(ii)*x);
    integrand(isnan(integrand)) = 0;
    Q(ii) = trapz(integrand);
    if abs(integrand(end)/Q(ii)) > 1e-4
        error('Numerical inaccuracy.');
    elseif abs(integrand(end)/Q(ii)) > 1e-6
        warning('Numerical inaccuracy.');
    end
end
Q = t(2) * Q;

end
