function plot_3d_farfield_sub(theta, phi, W)

% Define unit vector R in xyz-coordinates for far-field angles.
x = sin(theta) .* cos(phi);
y = sin(theta) .* sin(phi);
z = cos(theta);

% Surface plot of radiation pattern.
surf(x.*W, y.*W, z.*W, W);
shading interp;
set(gca, 'Projection', 'perspective');
caxis([0 1]);
colormap(jet(256));
axis image;
axis off;
view(22, 22);
set(gca, 'CameraViewAngle', 4.7);  % set zoom level

% Plot the x-, y-, and z-axes and colored rings around them.
rr = 1.2;
ra = 1.8;
hold on;
plot3([-rr ra], [0 0], [0 0], 'r-', 'LineWidth', 2);
plot3([0 0], [-rr ra], [0 0], 'g-', 'LineWidth', 2);
plot3([0 0], [0 0], [-rr ra], 'b-', 'LineWidth', 2);
text(ra+0.1, 0, 0, 'x', 'Color', 'r', 'FontSize', 12);
text(0, ra+0.1, 0, 'y', 'Color', 'g', 'FontSize', 12);
text(0, 0, ra+0.1, 'z', 'Color', 'b', 'FontSize', 12);
phi = linspace(-pi, pi, 37);
a0 = zeros(size(phi));
a1 = rr*cos(phi);
a2 = rr*sin(phi);
plot3(a0, a1, a2, 'r-', 'LineWidth', 2);
plot3(a2, a0, a1, 'g-', 'LineWidth', 2);
plot3(a1, a2, a0, 'b-', 'LineWidth', 2);
axis((ra+0.1)*[-1 1 -1 1 -1 1]);

end
